@@ -1,7 +1,7 @@
 import itertools
 import sys
 import six
-from .arbitrary import Arbitrary
+from .arbitraries.arbitrary import Arbitrary
 
 
 __all__ = ['for_all', 'Result', 'ReturnedFalse', 'CheckError']
